==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libkom++/personal-flags.h <==
// Personal flags.
//
// $Id: personal-flags.h,v 1.3 1994/07/16 17:45:37 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PERSONAL_FLAGS__
#define PERSONAL_FLAGS__

#include "misc.h"

class LyStr;

/*
 * Flags in the Person struct.
 */
class Personal_flags {
  public:
    Personal_flags();
    Personal_flags(const Personal_flags&);

    const Personal_flags &operator =(const Personal_flags&);

    friend Personal_flags parse_personal_flags(LyStr &prot_a_str);

    Bool unread_is_secret() const;
  private:
   /* FALSE if everyone is allowed to ask how 
    many unread texts you have.	*/
    unsigned int  pf_unread_is_secret : 1;
    unsigned int  flg2	: 1;
    unsigned int  flg3	: 1;
    unsigned int  flg4	: 1;
    unsigned int  flg5	: 1;
    unsigned int  flg6	: 1;
    unsigned int  flg7	: 1;
    unsigned int  flg8	: 1;
};

Personal_flags parse_personal_flags(LyStr &prot_a_str);
#endif

==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libkom++/personal-flags.h <==
// Personal flags.
//
// $Id: personal-flags.h,v 1.5 1995/11/18 22:49:59 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_PERSONAL_FLAGS_H
#define KOMXX_PERSONAL_FLAGS_H

#include "misc.h"

class LyStr;

/*
 * Flags in the Person struct.
 */
class Personal_flags {
  public:
    Personal_flags();
    Personal_flags(const Personal_flags&);

    const Personal_flags &operator =(const Personal_flags&);

    friend Personal_flags parse_personal_flags(LyStr &prot_a_str);

    bool unread_is_secret() const;
  private:
   /* FALSE if everyone is allowed to ask how 
    many unread texts you have.	*/
    unsigned int  pf_unread_is_secret : 1;
    unsigned int  flg2	: 1;
    unsigned int  flg3	: 1;
    unsigned int  flg4	: 1;
    unsigned int  flg5	: 1;
    unsigned int  flg6	: 1;
    unsigned int  flg7	: 1;
    unsigned int  flg8	: 1;
};

Personal_flags parse_personal_flags(LyStr &prot_a_str);
#endif
